.modal-dialog-button, .notification-button {
  color: rgba(0, 0, 0, 0.87);
  background-color: #fff;
  border-color: transparent;
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.4);
  text-shadow: none;
  icon-shadow: none;
  transition-duration: 100ms;
  font-size: 10.5pt;
  font-weight: 500;
  min-height: 32px;
  padding: 0 16px;
  border-radius: 4px;
}

.modal-dialog-button:focus, .notification-button:focus {
  color: rgba(0, 0, 0, 0.87);
  text-shadow: none;
  icon-shadow: none;
  box-shadow: 0 2px 8px rgba(0, 0, 0, 0.44);
}

.modal-dialog-button:hover, .notification-button:hover, .modal-dialog-button:checked, .notification-button:checked {
  color: rgba(0, 0, 0, 0.87);
  background-color: #fff;
  border-color: transparent;
  box-shadow: 0 2px 8px rgba(0, 0, 0, 0.44);
  text-shadow: none;
  icon-shadow: none;
}

.modal-dialog-button:active, .notification-button:active {
  color: rgba(0, 0, 0, 0.87);
  background-color: rgba(205, 205, 205, 0.9688);
  border-color: transparent;
  box-shadow: 0 5px 16px rgba(0, 0, 0, 0.5);
  text-shadow: none;
  icon-shadow: none;
  transition-duration: 200ms;
}

.modal-dialog-button:insensitive, .notification-button:insensitive {
  color: rgba(0, 0, 0, 0.38);
  background-color: rgba(0, 0, 0, 0.08);
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.sound-player StButton, .keyboard-key, .notification-icon-button {
  color: rgba(0, 0, 0, 0.87);
  background-color: #fff;
  border-color: transparent;
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.4);
  text-shadow: none;
  icon-shadow: none;
  transition-duration: 100ms;
  min-height: 32px;
  min-width: 32px;
  padding: 6px;
  border-radius: 4px;
}

.sound-player StButton:focus, .keyboard-key:focus, .notification-icon-button:focus {
  color: rgba(0, 0, 0, 0.87);
  text-shadow: none;
  icon-shadow: none;
  box-shadow: 0 2px 8px rgba(0, 0, 0, 0.44);
}

.sound-player StButton:hover, .keyboard-key:hover, .notification-icon-button:hover, .sound-player StButton:checked, .keyboard-key:checked, .notification-icon-button:checked {
  color: rgba(0, 0, 0, 0.87);
  background-color: #fff;
  border-color: transparent;
  box-shadow: 0 2px 8px rgba(0, 0, 0, 0.44);
  text-shadow: none;
  icon-shadow: none;
}

.sound-player StButton:active, .keyboard-key:active, .notification-icon-button:active {
  color: rgba(0, 0, 0, 0.87);
  background-color: rgba(205, 205, 205, 0.9688);
  border-color: transparent;
  box-shadow: 0 5px 16px rgba(0, 0, 0, 0.5);
  text-shadow: none;
  icon-shadow: none;
  transition-duration: 200ms;
}

.sound-player StButton:insensitive, .keyboard-key:insensitive, .notification-icon-button:insensitive {
  color: rgba(0, 0, 0, 0.38);
  background-color: rgba(0, 0, 0, 0.08);
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.sound-player .slider, .popup-slider-menu-item, .slider {
  height: 20px;
  color: #1967d2;
  -slider-height: 2px;
  -slider-background-color: rgba(0, 0, 0, 0.26);
  -slider-border-color: transparent;
  -slider-active-background-color: #1967d2;
  -slider-active-border-color: transparent;
  -slider-border-width: 0;
  -slider-handle-radius: 6px;
}

.popup-separator-menu-item, .separator {
  -gradient-height: 1px;
  -gradient-start: rgba(0, 0, 0, 0.12);
  -gradient-end: rgba(0, 0, 0, 0.12);
  -margin-horizontal: 4px;
  height: 1.5em;
}

#menu-search-entry, .run-dialog-entry, #notification StEntry {
  transition-duration: 100ms;
  background-color: rgba(0, 0, 0, 0.04);
  border-color: transparent;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.26);
  width: 250px;
  min-height: 32px;
  padding: 0 8px;
  border-radius: 4px 4px 0 0;
  color: rgba(0, 0, 0, 0.87);
  caret-color: rgba(0, 0, 0, 0.87);
  selection-background-color: rgba(25, 103, 210, 0.24);
  selected-color: rgba(0, 0, 0, 0.87);
}

#menu-search-entry:focus, .run-dialog-entry:focus, #notification StEntry:focus {
  border-color: transparent;
  box-shadow: inset 0 -2px #1967d2;
  padding: 0 8px;
  border-width: 0;
  color: rgba(0, 0, 0, 0.87);
}

.photoframe-box, .desklet-header, .desklet-with-borders-and-header, .desklet-with-borders {
  color: rgba(0, 0, 0, 0.87);
  border: none;
  padding: 12px;
  box-shadow: 0 5px 16px rgba(0, 0, 0, 0.5);
}

.calendar-change-month-forward, .calendar-change-month-back {
  width: 16px;
  height: 16px;
  border-radius: 999px;
  transition-duration: 100ms;
}

.calendar-change-month-forward:active, .calendar-change-month-back:active {
  background-color: rgba(0, 0, 0, 0.26);
}

.popup-combo-menu, .menu {
  background-color: #fff;
  border-radius: 4px;
  color: rgba(0, 0, 0, 0.87);
  box-shadow: 0 2px 8px rgba(0, 0, 0, 0.44);
}

.menu-category-button-label:ltr, .menu-application-button-label:ltr {
  padding-left: 4px;
}

.menu-category-button-label:rtl, .menu-application-button-label:rtl {
  padding-right: 4px;
}

.mount-question-dialog-subject, .show-processes-dialog-subject {
  font-weight: bold;
  color: rgba(0, 0, 0, 0.87);
  padding-top: 10px;
  padding-left: 17px;
  padding-bottom: 6px;
}

.mount-question-dialog-subject:rtl, .show-processes-dialog-subject:rtl {
  padding-left: 0;
  padding-right: 17px;
}

.mount-question-dialog-description, .show-processes-dialog-description {
  color: rgba(0, 0, 0, 0.87);
  padding-left: 17px;
  width: 28em;
}

.check-box:focus StBin, .check-box StBin {
  width: 24px;
  height: 24px;
  padding: 4px;
  border-radius: 100px;
  background-image: url(assets/checkbox-off.svg);
}

.radiobutton:focus StBin, .radiobutton StBin {
  width: 20px;
  height: 20px;
  padding: 6px;
  border-radius: 100px;
  background-image: url(assets/radiobutton-off.svg);
}

.tile-hud, .tile-preview {
  background-color: rgba(0, 0, 0, 0.3);
  border: 2px solid rgba(0, 0, 0, 0.12);
}

.tile-hud.snap, .tile-preview.snap {
  background-color: rgba(0, 0, 0, 0.3);
  border: 2px solid #1967d2;
}

.osd-window, .modal-dialog, .switcher-list, #LookingGlassDialog, .workspace-osd, .info-osd, .overview-empty-placeholder {
  color: rgba(0, 0, 0, 0.87);
  background-color: #fff;
  border: none;
  border-radius: 4px;
  padding: 12px;
  box-shadow: 0 5px 16px rgba(0, 0, 0, 0.5);
}

.workspace-osd, .info-osd, .overview-empty-placeholder {
  font-size: 15pt;
  font-weight: 500;
  text-align: center;
  padding: 8px 10px;
}

stage {
  font-size: 10.5pt;
  font-weight: 400;
  font-family: "M+ 1c", Roboto, Cantarell, Sans-Serif;
  color: rgba(0, 0, 0, 0.87);
}

.cinnamon-link {
  color: #1967d2;
  font-style: italic;
}

.cinnamon-link:hover {
  color: #1967d2;
}

.label-shadow {
  color: transparent;
}

StScrollBar {
  padding: 0px;
}

StScrollBar StButton#vhandle, StScrollBar StButton#hhandle {
  background-color: rgba(0, 0, 0, 0.38);
  border-radius: 100px;
  margin: 4px;
}

StScrollBar StButton#vhandle:hover, StScrollBar StButton#hhandle:hover {
  background-color: rgba(0, 0, 0, 0.6);
}

StScrollBar StBin#trough {
  margin: 4px;
  border-radius: 100px;
  background-color: rgba(0, 0, 0, 0.12);
}

StScrollView.vfade {
  -st-vfade-offset: 32px;
}

StScrollView.hfade {
  -st-hfade-offset: 32px;
}

StScrollView StScrollBar {
  min-width: 16px;
  min-height: 16px;
}

#Tooltip {
  font-size: 9pt;
  font-weight: 400;
  padding: 6px 8px;
  color: #fff;
  text-align: center;
  border-radius: 4px;
  background-color: rgba(97, 97, 97, 0.9);
}

.menu {
  min-width: 100px;
  margin: 4px;
}

.menu-top-box {
  spacing: 5px;
}

.menu-systembuttons-box {
  padding: 10px;
}

.popup-sub-menu {
  background-color: rgba(0, 0, 0, 0.04);
}

.popup-menu-arrow {
  icon-size: 1.14em;
}

.popup-combo-menu {
  padding: 8px 0;
}

.popup-menu-content {
  padding: 8px 0;
}

.popup-menu-item {
  padding: 0.4em 16px;
  spacing: 8px;
  transition-duration: 100ms;
}

.popup-menu-item:active {
  background-color: rgba(0, 0, 0, 0.08);
  color: rgba(0, 0, 0, 0.87);
  transition-duration: 0ms;
}

.popup-menu-item:insensitive {
  color: rgba(0, 0, 0, 0.38);
}

.popup-image-menu-item {
  color: rgba(0, 0, 0, 0.6);
}

.popup-combobox-item {
  padding: 0.4em 16px;
}

.popup-device-menu-item {
  spacing: .5em;
}

.popup-inactive-menu-item {
  color: rgba(0, 0, 0, 0.87);
}

.popup-inactive-menu-item:insensitive {
  color: rgba(0, 0, 0, 0.38);
}

.popup-subtitle-menu-item {
  font-size: 10.5pt;
  font-weight: 500;
}

.popup-menu-icon {
  icon-size: 1.14em;
}

.popup-alternating-menu-item:alternate {
  font-size: 10.5pt;
  font-weight: 500;
}

.toggle-switch {
  width: 40px;
  height: 20px;
}

.toggle-switch-us, .toggle-switch-intl {
  background-image: url(assets/toggle-off.svg);
}

.toggle-switch-us:checked, .toggle-switch-intl:checked {
  background-image: url(assets/toggle-on.svg);
}

.nm-menu-item-icons {
  spacing: .5em;
  icon-size: 1.14em;
}

#panel {
  color: rgba(0, 0, 0, 0.6);
  background-color: rgba(0, 0, 0, 0.6);
  height: 2.5em;
  width: 3.2em;
}

#panel:highlight {
  background-color: rgba(0, 0, 0, 0.26);
}

.panel-dummy {
  background-color: rgba(255, 0, 0, 0.6);
}

.panel-dummy:entered {
  background-color: rgba(0, 255, 0, 0.6);
}

.panelLeft {
  spacing: 4px;
}

.panelLeft:dnd {
  background-color: rgba(255, 0, 0, 0.6);
}

.panelLeft:ltr {
  padding-right: 4px;
}

.panelLeft:rtl {
  padding-left: 4px;
}

.panelLeft.vertical {
  padding: 0;
}

.panelCenter {
  spacing: 4px;
}

.panelCenter:dnd {
  background-color: rgba(0, 255, 0, 0.6);
}

.panelCenter.vertical {
  padding-left: 0;
  padding-right: 0;
}

.panelRight {
  spacing: 4px;
}

.panelRight:dnd {
  background-color: rgba(0, 0, 255, 0.6);
}

.panelRight:ltr {
  padding-left: 0;
  spacing: 0;
}

.panelRight:rtl {
  padding-right: 0;
  spacing: 0;
}

.panelRight.vertical {
  padding: 0;
}

.panel-top .window-list-item-box:hover {
  box-shadow: 0 3px 0 0 #1967d2 inset;
}

.panel-top .window-list-item-box:active:hover, .panel-top .window-list-item-box:checked:hover, .panel-top .window-list-item-box:focus:hover {
  box-shadow: 0 3px 0 0 #1967d2 inset;
}

.panel-top .grouped-window-list-item-box:hover {
  box-shadow: 0 3px 0 0 #1967d2 inset;
}

.panel-top .grouped-window-list-item-box:active:hover, .panel-top .grouped-window-list-item-box:checked:hover {
  box-shadow: 0 3px 0 0 #1967d2 inset;
}

.panel-top .grouped-window-list-item-box:focus:hover {
  box-shadow: 0 3px 0 0 #1967d2 inset;
}

.panel-top .grouped-window-list-badge {
  margin-top: 2px;
}

.panel-top .workspace-switcher, .panel-top .workspace-graph, .panel-top .workspace-button {
  padding: 1px 4px;
}

.panel-top .workspace-graph:hover, .panel-top .workspace-button:hover {
  box-shadow: 0 3px 0 0 #1967d2 inset;
}

.panel-top .applet-box {
  padding: 0 4px;
}

.panel-top .applet-box:hover {
  box-shadow: 0 3px 0 0 #1967d2 inset;
}

.panel-top .panel-launchers .launcher:hover {
  box-shadow: 0 3px 0 0 #1967d2 inset;
}

.panel-top .applet-separator {
  padding: 3px 4px;
}

.panel-top .systray:hover {
  box-shadow: 0 4px 0 0 #1967d2 inset;
}

.panel-bottom .window-list-item-box:hover {
  box-shadow: 0 -3px 0 0 #1967d2 inset;
}

.panel-bottom .window-list-item-box:active:hover, .panel-bottom .window-list-item-box:checked:hover, .panel-bottom .window-list-item-box:focus:hover {
  box-shadow: 0 -3px 0 0 #1967d2 inset;
}

.panel-bottom .grouped-window-list-item-box:hover {
  box-shadow: 0 -3px 0 0 #1967d2 inset;
}

.panel-bottom .grouped-window-list-item-box:active:hover, .panel-bottom .grouped-window-list-item-box:checked:hover {
  box-shadow: 0 -3px 0 0 #1967d2 inset;
}

.panel-bottom .grouped-window-list-item-box:focus:hover {
  box-shadow: 0 -3px 0 0 #1967d2 inset;
}

.panel-bottom .workspace-switcher, .panel-bottom .workspace-graph, .panel-bottom .workspace-button {
  padding: 1px 4px;
}

.panel-bottom .workspace-graph:hover, .panel-bottom .workspace-button:hover {
  box-shadow: 0 -3px 0 0 #1967d2 inset;
}

.panel-bottom .applet-box {
  padding: 0 4px;
}

.panel-bottom .applet-box:hover {
  box-shadow: 0 -3px 0 0 #1967d2 inset;
}

.panel-bottom .panel-launchers .launcher:hover {
  box-shadow: 0 -3px 0 0 #1967d2 inset;
}

.panel-bottom .applet-separator {
  padding: 3px 4px;
}

.panel-bottom .systray:hover {
  box-shadow: 0 4px 0 0 #1967d2 inset;
}

.panel-left .window-list-item-box:hover {
  box-shadow: 3px 0 0 0 #1967d2 inset;
}

.panel-left .window-list-item-box:active:hover, .panel-left .window-list-item-box:checked:hover, .panel-left .window-list-item-box:focus:hover {
  box-shadow: 3px 0 0 0 #1967d2 inset;
}

.panel-left .grouped-window-list-item-box:hover {
  box-shadow: 3px 0 0 0 #1967d2 inset;
}

.panel-left .grouped-window-list-item-box:active:hover, .panel-left .grouped-window-list-item-box:checked:hover {
  box-shadow: 3px 0 0 0 #1967d2 inset;
}

.panel-left .grouped-window-list-item-box:focus:hover {
  box-shadow: 3px 0 0 0 #1967d2 inset;
}

.panel-left .grouped-window-list-badge {
  margin-left: 2px;
}

.panel-left .workspace-switcher, .panel-left .workspace-graph, .panel-left .workspace-button {
  padding: 4px 1px;
  min-height: 1.2em;
}

.panel-left .workspace-graph:hover, .panel-left .workspace-button:hover {
  box-shadow: 3px 0 0 0 #1967d2 inset;
}

.panel-left .applet-box {
  padding: 4px 0;
}

.panel-left .applet-box:hover {
  box-shadow: 3px 0 0 0 #1967d2 inset;
}

.panel-left .panel-launchers .launcher:hover {
  box-shadow: 3px 0 0 0 #1967d2 inset;
}

.panel-left .applet-separator {
  padding: 4px 3px;
}

.panel-left .systray:hover {
  box-shadow: 4px 0 0 0 #1967d2 inset;
}

.panel-right .window-list-item-box:hover {
  box-shadow: -3px 0 0 0 #1967d2 inset;
}

.panel-right .window-list-item-box:active:hover, .panel-right .window-list-item-box:checked:hover, .panel-right .window-list-item-box:focus:hover {
  box-shadow: -3px 0 0 0 #1967d2 inset;
}

.panel-right .grouped-window-list-item-box:hover {
  box-shadow: -3px 0 0 0 #1967d2 inset;
}

.panel-right .grouped-window-list-item-box:active:hover, .panel-right .grouped-window-list-item-box:checked:hover {
  box-shadow: -3px 0 0 0 #1967d2 inset;
}

.panel-right .grouped-window-list-item-box:focus:hover {
  box-shadow: -3px 0 0 0 #1967d2 inset;
}

.panel-right .workspace-switcher, .panel-right .workspace-graph, .panel-right .workspace-button {
  padding: 4px 1px;
  min-height: 1.2em;
}

.panel-right .workspace-graph:hover, .panel-right .workspace-button:hover {
  box-shadow: -3px 0 0 0 #1967d2 inset;
}

.panel-right .applet-box {
  padding: 4px 0;
}

.panel-right .applet-box:hover {
  box-shadow: -3px 0 0 0 #1967d2 inset;
}

.panel-right .panel-launchers .launcher:hover {
  box-shadow: -3px 0 0 0 #1967d2 inset;
}

.panel-right .applet-separator {
  padding: 4px 3px;
}

.panel-right .systray:hover {
  box-shadow: -4px 0 0 0 #1967d2 inset;
}

.panel-status-button {
  font-size: 10.5pt;
  font-weight: 500;
  -natural-hpadding: 4px;
  -minimum-hpadding: 4px;
  color: rgba(0, 0, 0, 0.6);
}

.panel-status-button:hover {
  color: rgba(0, 0, 0, 0.87);
}

.system-status-icon {
  icon-size: 1.14em;
  padding: 0;
  spacing: 0;
}

.system-status-icon.warning {
  color: #f9ab00;
}

.system-status-icon.error {
  color: #d93025;
}

#overview {
  spacing: 12px;
}

.window-caption {
  font-size: 9pt;
  font-weight: 400;
  background-color: rgba(0, 0, 0, 0.01);
  color: rgba(0, 0, 0, 0.6);
  padding: 4px 6px;
  text-align: center;
  height: 1.5em;
  -cinnamon-caption-spacing: 12px;
}

#selected.window-caption, .window-caption:focus {
  color: rgba(0, 0, 0, 0.87);
  box-shadow: 0 -3px 0 0 #1967d2 inset;
}

.workspace-controls {
  visible-height: 32px;
}

.workspace-thumbnails-background {
  color: rgba(0, 0, 0, 0.6);
  background-color: rgba(255, 255, 255, 0.08);
  border: none;
  padding: 8px;
  border-radius: 4px 0 0 4px;
}

.workspace-thumbnails-background:rtl {
  border-radius: 0 4px 4px 0;
}

.workspace-thumbnails {
  spacing: 32px;
}

.workspace-add-button {
  background-image: url(assets/add-workspace.svg);
  height: 200px;
  width: 35px;
  transition-duration: shorter_duration;
}

.workspace-add-button:hover {
  background-image: url(assets/add-workspace-hover.svg);
}

.workspace-add-button:active {
  background-image: url(assets/add-workspace-active.svg);
}

.workspace-close-button, .window-close {
  background-image: url(assets/window-close.svg);
  height: 32px;
  width: 32px;
  -cinnamon-close-overlap: 20px;
}

.workspace-close-button:hover, .window-close:hover {
  background-image: url(assets/window-close-hover.svg);
}

.workspace-close-button:active, .window-close:active {
  background-image: url(assets/window-close-active.svg);
}

.workspace-close-button:rtl, .window-close:rtl {
  -st-background-image-shadow: 2px 2px 6px rgba(0, 0, 0, 0.5);
}

.window-border {
  border: 1px solid rgba(0, 0, 0, 0.12);
}

.window-close-area {
  background-image: url(assets/trash-icon.png);
  background-size: 100px;
  background-color: rgba(0, 0, 0, 0.3);
  border: 1px solid rgba(0, 0, 0, 0.12);
  border-bottom-width: 0;
  border-radius: 20px 20px 0 0;
  height: 120px;
  width: 400px;
}

.expo-background {
  background-color: rgba(0, 0, 0, 0.6);
}

.workspace-overview-background-shade {
  background-color: rgba(0, 0, 0, 0.6);
}

.expo-workspace-thumbnail-frame {
  border: 1px solid rgba(0, 0, 0, 0.12);
}

#active.expo-workspace-thumbnail-frame {
  border: 1px solid #1967d2;
}

#LookingGlassDialog {
  spacing: 4px;
  padding: 8px;
}

.calendar {
  padding: 4px 8px;
  spacing-rows: 2px;
  spacing-columns: 4px;
}

.datemenu-date-label {
  font-size: 15pt;
  font-weight: 500;
  height: 24px;
  margin: 2px;
  padding: 6px 16px;
  border-radius: 4px;
  color: rgba(0, 0, 0, 0.87);
  text-align: center;
}

.datemenu-date-label:focus {
  background-color: rgba(0, 0, 0, 0.12);
}

.calendar-month-label {
  font-size: 10.5pt;
  font-weight: 500;
  height: 16px;
  margin: 2px;
  padding: 6px 16px;
  border-radius: 4px;
  color: rgba(0, 0, 0, 0.87);
  text-align: center;
}

.calendar-month-label:focus {
  background-color: rgba(0, 0, 0, 0.12);
}

.calendar-change-month-back {
  background-image: url(assets/calendar-arrow-left.svg);
}

.calendar-change-month-back:rtl {
  background-image: url(assets/calendar-arrow-right.svg);
}

.calendar-change-month-forward {
  background-image: url(assets/calendar-arrow-right.svg);
}

.calendar-change-month-forward:rtl {
  background-image: url(assets/calendar-arrow-left.svg);
}

.calendar-day-base {
  font-size: 9pt;
  font-weight: 400;
  text-align: center;
  width: 28px;
  height: 28px;
  padding: 0;
  margin: 2px;
  border-radius: 100px;
}

.calendar-day-base:hover, .calendar-day-base:focus {
  background-color: rgba(0, 0, 0, 0.26);
}

.calendar-day-base:active {
  color: #fff;
  background-color: #1967d2;
  border-color: transparent;
}

.calendar-week-number {
  font-size: 9pt;
  font-weight: 400;
  width: 21px;
  height: 28px;
  margin: 2px;
  padding: 0;
  border-radius: 100px;
  background-color: transparent;
  color: rgba(0, 0, 0, 0.38);
  text-align: center;
}

.calendar-day-heading {
  font-size: 9pt;
  font-weight: 400;
  width: 28px;
  height: 21px;
  margin: 2px;
  padding: 0;
  border-radius: 100px;
  background-color: transparent;
  color: rgba(0, 0, 0, 0.38);
  text-align: center;
}

.calendar-day {
  border-width: 0;
}

.calendar-day-top {
  border-top-width: 0;
}

.calendar-day-left {
  border-left-width: 0;
}

.calendar-nonwork-day {
  color: rgba(0, 0, 0, 0.87);
}

.calendar-today {
  font-weight: bold;
  border: none;
}

.calendar-day-with-events {
  color: #1967d2;
  font-weight: normal;
  text-decoration: underline;
  background-image: none;
}

.calendar-other-month-day {
  color: rgba(0, 0, 0, 0.26);
  opacity: 0.5;
}

.calendar-week-number {
  width: 28px;
  height: 21px;
  margin: 2px;
  padding: 7px 0 0;
  border-radius: 100px;
  background-color: transparent;
  color: rgba(0, 0, 0, 0.38);
  font-size: inherit;
  font-weight: bold;
  text-align: center;
}

#notification {
  background-color: #fff;
  border-radius: 4px;
  border: 1px solid rgba(0, 0, 0, 0.12);
  padding: 8px;
  spacing-rows: 4px;
  spacing-columns: 8px;
  margin-from-right-edge-of-screen: 20px;
  width: 34em;
  color: rgba(0, 0, 0, 0.87);
  box-shadow: 0 2px 8px rgba(0, 0, 0, 0.44);
}

#notification.multi-line-notification {
  padding-bottom: 8px;
}

#notification .url-highlighter {
  link-color: #1967d2;
}

.notification-with-image {
  min-height: 159px;
  color: rgba(0, 0, 0, 0.87);
}

#notification-scrollview {
  max-height: 10em;
}

#notification-scrollview > .top-shadow {
  height: 1em;
}

#notification-scrollview > .bottom-shadow {
  height: 1em;
}

#notification-scrollview:ltr > StScrollBar {
  padding-left: 6px;
}

#notification-scrollview:rtl > StScrollBar {
  padding-right: 6px;
}

#notification-body {
  spacing: 4px;
}

#notification-actions {
  spacing: 8px;
}

.notification-icon-button > StIcon {
  icon-size: 1.5em;
}

#altTabPopup {
  padding: 8px;
  spacing: 16px;
}

.switcher-list {
  transition-duration: 100ms;
}

.switcher-list .item-box {
  padding: 8px;
  border-radius: 4px;
}

.switcher-list .item-box:selected {
  background-color: rgba(0, 0, 0, 0.12);
}

.switcher-list .thumbnail-box {
  padding: 2px;
  spacing: 4px;
}

.switcher-list .thumbnail {
  width: 256px;
}

.switcher-list .separator {
  width: 1px;
  background: rgba(0, 0, 0, 0.12);
}

.switcher-list-item-container {
  spacing: 8px;
}

.thumbnail-scroll-gradient-left {
  background-gradient-direction: horizontal;
  background-gradient-start: #333333;
  background-gradient-end: rgba(51, 51, 51, 0);
  border-radius: 4px;
  border-radius-topright: 0;
  border-radius-bottomright: 0;
  width: 60px;
}

.thumbnail-scroll-gradient-right {
  background-gradient-direction: horizontal;
  background-gradient-start: rgba(51, 51, 51, 0);
  background-gradient-end: #333333;
  border-radius: 4px;
  border-radius-topleft: 0;
  border-radius-bottomleft: 0;
  width: 60px;
}

.switcher-arrow {
  border-color: rgba(0, 0, 0, 0);
  color: rgba(0, 0, 0, 0.6);
}

.switcher-arrow:highlighted {
  color: rgba(0, 0, 0, 0.87);
}

.switcher-preview-backdrop {
  background-color: rgba(0, 0, 0, 0.6);
}

.ripple-box {
  width: 104px;
  height: 104px;
  background-image: url(assets/corner-ripple.png);
  background-color: #1967d2;
  border-radius: 52px;
}

.modal-dialog {
  padding: 16px 20px;
}

.modal-dialog-button-box {
  spacing: 16px;
}

.run-dialog-label {
  color: rgba(0, 0, 0, 0.6);
  padding-bottom: .4em;
}

.run-dialog-error-label {
  color: #d93025;
}

.run-dialog-error-box {
  padding-top: 16px;
  spacing: 6px;
}

.run-dialog-completion-box {
  padding-left: 15px;
}

.run-dialog {
  border-radius: 4px;
  padding: 16px 20px;
}

.lightbox {
  background-color: rgba(0, 0, 0, 0.3);
}

.cinnamon-mount-operation-icon {
  icon-size: 4.8em;
}

.mount-password-reask {
  color: #f9ab00;
}

.show-processes-dialog {
  spacing: 24px;
}

.mount-question-dialog {
  spacing: 24px;
}

.show-processes-dialog-description:rtl {
  padding-right: 17px;
}

.mount-question-dialog-description:rtl {
  padding-right: 17px;
}

.show-processes-dialog-app-list {
  max-height: 200px;
  padding-top: 24px;
  padding-left: 49px;
  padding-right: 32px;
}

.show-processes-dialog-app-list:rtl {
  padding-right: 49px;
  padding-left: 32px;
}

.show-processes-dialog-app-list-item {
  color: rgba(0, 0, 0, 0.87);
}

.show-processes-dialog-app-list-item:hover {
  color: rgba(0, 0, 0, 0.87);
}

.show-processes-dialog-app-list-item:ltr {
  padding-right: 1em;
}

.show-processes-dialog-app-list-item:rtl {
  padding-left: 1em;
}

.show-processes-dialog-app-list-item-icon:ltr {
  padding-right: 17px;
}

.show-processes-dialog-app-list-item-icon:rtl {
  padding-left: 17px;
}

.magnifier-zoom-region {
  border: 3px solid rgba(0, 0, 0, 0.12);
}

.magnifier-zoom-region.full-screen {
  border-width: 0;
}

#keyboard {
  background-color: rgba(0, 0, 0, 0.6);
}

.keyboard-key {
  font-size: 10.5pt;
  font-weight: 500;
}

.keyboard-layout {
  spacing: 8px;
  padding: 8px;
}

.keyboard-row {
  spacing: 16px;
}

.keyboard-subkeys {
  color: inherit;
  padding: 5px;
  -arrow-border-radius: 0;
  -arrow-background-color: transparent;
  -arrow-border-width: 0;
  -arrow-border-color: transparent;
  -arrow-base: 0;
  -arrow-rise: 0;
  -boxpointer-gap: 5px;
  background-color: #fff;
  border-radius: 4px;
  box-shadow: 0 2px 8px rgba(0, 0, 0, 0.44);
}

.menu-favorites-box {
  padding: 8px;
}

.menu-favorites-button {
  padding: 0.4em 4px;
}

.menu-favorites-button:hover {
  background-color: rgba(0, 0, 0, 0.12);
  border-radius: 4px;
  color: rgba(0, 0, 0, 0.87);
}

.menu-categories-box {
  padding: 8px;
}

.menu-applications-inner-box {
  padding: 8px;
}

.menu-applications-outer-box {
  padding: 8px;
  border-radius: 4px;
}

.menu-application-button {
  padding: 0.4em 4px;
}

.menu-application-button:highlighted {
  font-weight: bold;
}

.menu-application-button-selected {
  padding: 0.4em 4px;
  background-color: rgba(0, 0, 0, 0.12);
  border-radius: 4px;
  color: rgba(0, 0, 0, 0.87);
}

.menu-application-button-selected:highlighted {
  font-weight: bold;
}

.menu-category-button {
  padding: 0.4em 4px;
}

.menu-category-button-greyed {
  padding: 0.4em 4px;
  color: rgba(0, 0, 0, 0.6);
  font-style: italic;
}

.menu-category-button-selected {
  padding: 0.4em 4px;
  background-color: rgba(0, 0, 0, 0.12);
  border-radius: 4px;
  color: rgba(0, 0, 0, 0.87);
}

.menu-selected-app-box {
  padding: 8px;
  margin-bottom: 4px;
  text-align: right;
}

.menu-selected-app-box:rtl {
  text-align: left;
}

.menu-selected-app-title {
  font-size: 9pt;
  font-weight: 400;
}

.menu-selected-app-description {
  font-size: 9pt;
  font-weight: 400;
  max-width: 150px;
}

.menu-search-box:ltr {
  padding-left: 30px;
  padding-bottom: 5px;
  padding-top: 5px;
}

.menu-search-box:rtl {
  padding-right: 30px;
  padding-bottom: 5px;
  padding-top: 5px;
}

.menu-search-entry-icon {
  icon-size: 1em;
  padding: 0 0;
  color: rgba(0, 0, 0, 0.38);
}

.window-list-box {
  font-size: 9pt;
  font-weight: 400;
  spacing: 4px;
  padding: 0 3px;
}

.window-list-box.vertical {
  spacing: 4px;
  padding: 3px 0;
}

.window-list-box:highlight {
  background: rgba(0, 0, 0, 0.26);
  color: rgba(0, 0, 0, 0.87);
}

.window-list-item-box {
  background-color: rgba(0, 0, 0, 0.01);
  transition-duration: 100ms;
}

.window-list-item-box:hover {
  color: rgba(0, 0, 0, 0.87);
}

.window-list-item-box:active, .window-list-item-box:checked, .window-list-item-box:focus {
  background-color: rgba(0, 0, 0, 0.26);
  color: rgba(0, 0, 0, 0.87);
}

.window-list-item-box:active:hover, .window-list-item-box:checked:hover, .window-list-item-box:focus:hover {
  color: rgba(0, 0, 0, 0.87);
}

.window-list-item-box .progress {
  background-color: #1e8e3e;
}

.window-list-item-box.top StLabel, .window-list-item-box.bottom StLabel {
  padding-left: 3px;
}

.window-list-item-demands-attention {
  background-color: #f0f0f0;
  color: rgba(0, 0, 0, 0.6);
}

.window-list-preview {
  background-color: #fff;
  border-radius: 4px;
  padding: 10px 15px;
  spacing: 1em;
  color: rgba(0, 0, 0, 0.87);
  box-shadow: 0 5px 16px rgba(0, 0, 0, 0.5);
}

.grouped-window-list-thumbnail-label {
  padding-left: 3px;
  padding-bottom: 6px;
}

.grouped-window-list-number-label {
  font-size: 9pt;
  font-weight: 400;
  z-index: 99;
}

.grouped-window-list-list-button-label {
  padding-left: 3px;
}

.grouped-window-list-badge {
  border-radius: 9999px;
  background-color: #e0e0e0;
}

.grouped-window-list-thumbnail-alert {
  background: #f9ab00;
}

.grouped-window-list-item-box {
  background-color: rgba(0, 0, 0, 0.01);
  transition-duration: 100ms;
}

.grouped-window-list-item-box:hover {
  color: rgba(0, 0, 0, 0.87);
}

.grouped-window-list-item-box:active, .grouped-window-list-item-box:checked {
  background-color: rgba(0, 0, 0, 0.12);
}

.grouped-window-list-item-box:active:hover, .grouped-window-list-item-box:checked:hover {
  color: rgba(0, 0, 0, 0.87);
}

.grouped-window-list-item-box:focus {
  background-color: rgba(0, 0, 0, 0.26);
  color: rgba(0, 0, 0, 0.87);
}

.grouped-window-list-item-box:focus:hover {
  color: rgba(0, 0, 0, 0.87);
}

.grouped-window-list-item-box .progress {
  background-color: #1e8e3e;
}

.grouped-window-list-item-demands-attention {
  background-color: #f0f0f0;
  color: rgba(0, 0, 0, 0.6);
}

.grouped-window-list-thumbnail-menu {
  padding: 20px;
  border: none;
  border-radius: 4px;
  color: rgba(0, 0, 0, 0.6);
  background: none;
}

.grouped-window-list-thumbnail-menu .item-box {
  padding: 8px;
  spacing: 2px;
  border-radius: 4px;
}

.grouped-window-list-thumbnail-menu .item-box:outlined {
  border: 2px solid rgba(0, 0, 0, 0.12);
  color: rgba(0, 0, 0, 0.87);
}

.grouped-window-list-thumbnail-menu .item-box:selected {
  background: rgba(0, 0, 0, 0.12);
  color: rgba(0, 0, 0, 0.87);
}

.grouped-window-list-thumbnail-menu .item-box > StBoxLayout:ltr {
  margin: 1px 0 0 6px;
}

.grouped-window-list-thumbnail-menu .item-box > StBoxLayout:rtl {
  margin: 1px 6px 0 0;
}

.grouped-window-list-thumbnail-menu .item-box > StBoxLayout StLabel {
  padding-bottom: 2px;
}

.grouped-window-list-thumbnail-menu .item-box > StButton:ltr {
  margin: 1px 6px 0 0;
}

.grouped-window-list-thumbnail-menu .item-box > StButton:rtl {
  margin: 1px 0 0 6px;
}

.grouped-window-list-thumbnail-menu .thumbnail-box {
  padding: 2px;
}

.grouped-window-list-thumbnail-menu .thumbnail {
  width: 256px;
}

.grouped-window-list-thumbnail-menu .separator {
  width: 1px;
  background: rgba(0, 0, 0, 0.12);
}

.sound-player StButton:small {
  min-width: 24px;
  min-height: 24px;
  padding: 4px;
}

.sound-player StButton:small StIcon {
  icon-size: 1em;
}

.sound-player StButton StIcon {
  icon-size: 1.5em;
}

.sound-player .slider {
  height: 5px;
}

.sound-player StBoxLayout {
  spacing: 0.5em;
}

.sound-player > StBoxLayout {
  padding: 5px;
}

.sound-player-generic-coverart {
  background: rgba(0, 0, 0, 0.2);
}

.sound-player-overlay {
  background-color: #fff;
  min-width: 300px;
  padding: 12px 16px;
  spacing: 0.5em;
  color: rgba(0, 0, 0, 0.6);
}

.workspace-button {
  background-color: #e0e0e0;
  width: 2em;
  height: 1em;
  color: rgba(0, 0, 0, 0.6);
  margin: 2px;
}

.workspace-button:outlined {
  background-color: rgba(0, 0, 0, 0.26);
  color: rgba(0, 0, 0, 0.87);
}

.workspace-graph {
  background-color: rgba(0, 0, 0, 0.6);
}

.workspace-graph .workspace {
  background-color: #e0e0e0;
  border: 1px solid rgba(0, 0, 0, 0.12);
}

.workspace-graph .workspace:active {
  background-color: rgba(0, 0, 0, 0.26);
  border: 1px solid rgba(0, 0, 0, 0.12);
}

.workspace-graph .workspace:active .windows {
  -active-window-background: rgba(255, 255, 255, 0.8);
  -active-window-border: rgba(0, 0, 0, 0.9);
  -inactive-window-background: rgba(140, 140, 140, 0.8);
  -inactive-window-border: rgba(0, 0, 0, 0.7);
}

.workspace-graph .workspace .windows {
  -active-window-background: rgba(140, 140, 140, 0.8);
  -active-window-border: rgba(0, 0, 0, 0.7);
  -inactive-window-background: rgba(140, 140, 140, 0.8);
  -inactive-window-border: rgba(0, 0, 0, 0.7);
}

.panel-launchers {
  padding: 0 4px;
  spacing: 4px;
  transition-duration: 100ms;
}

.panel-launchers .launcher {
  background-color: rgba(0, 0, 0, 0.01);
}

.panel-launchers.vertical {
  padding: 4px 0;
  spacing: 4px;
}

.panel-launchers.vertical .launcher .icon-box {
  padding-top: 0;
}

.applet-separator-line, .applet-separator-line-vertical {
  width: 2px;
  background: rgba(0, 0, 0, 0.12);
}

.applet-spacer:highlight {
  background: rgba(255, 255, 255, 0.4);
}

.applet-box {
  background-color: rgba(0, 0, 0, 0.01);
  color: rgba(0, 0, 0, 0.6);
  transition-duration: 100ms;
}

.applet-box:checked {
  color: rgba(0, 0, 0, 0.87);
}

.applet-box:checked .applet-label {
  color: rgba(0, 0, 0, 0.87);
}

.applet-box:hover {
  color: rgba(0, 0, 0, 0.87);
}

.applet-box:hover .applet-label {
  color: rgba(0, 0, 0, 0.87);
}

.applet-box:highlight {
  background: rgba(0, 0, 0, 0.26);
  color: rgba(0, 0, 0, 0.87);
}

.applet-box:highlight .applet-label {
  color: rgba(0, 0, 0, 0.87);
}

.applet-label {
  font-size: 10.5pt;
  font-weight: 500;
  color: rgba(0, 0, 0, 0.6);
}

.applet-icon {
  color: rgba(0, 0, 0, 0.6);
  padding: 0;
  spacing: 0;
  icon-size: 22px;
}

.desklet {
  font-size: 9pt;
  font-weight: 400;
  color: rgba(0, 0, 0, 0.87);
  border: none;
  box-shadow: 0 5px 16px rgba(0, 0, 0, 0.5);
  padding: 12px;
  background-color: rgba(0, 0, 0, 0.3);
  border-radius: 4px;
}

.desklet-with-borders {
  font-size: 9pt;
  font-weight: 400;
  background-color: #fff;
  border-radius: 4px;
}

.desklet-with-borders:highlight {
  background-color: rgba(255, 255, 255, 0.4);
}

.desklet-with-borders-and-header {
  font-size: 9pt;
  font-weight: 400;
  background-color: #fff;
  border-radius-bottomleft: 2px;
  border-radius-bottomright: 2px;
}

.desklet-with-borders-and-header:highlight {
  background-color: rgba(255, 255, 255, 0.4);
}

.desklet-header {
  font-size: 15pt;
  font-weight: 500;
  background-color: #fff;
  border-radius-topleft: 2px;
  border-radius-topright: 2px;
}

.desklet-header:highlight {
  background-color: rgba(255, 255, 255, 0.4);
}

.photoframe-box {
  background-color: #fff;
  border-radius: 4px;
}

.photoframe-box:highlight {
  background-color: rgba(255, 255, 255, 0.4);
}

.desklet-drag-placeholder {
  border: 2px solid #1967d2;
  background-color: rgba(0, 0, 0, 0.3);
  border-radius: 4px;
}

.launcher {
  padding: 1px;
}

.launcher .icon-box {
  padding-top: 2px;
}

.about-content {
  min-width: 250px;
  min-height: 150px;
  spacing: 8px;
  padding-bottom: 16px;
}

.about-title {
  font-size: 15pt;
  font-weight: 500;
}

.about-uuid {
  font-size: 9pt;
  font-weight: 400;
}

.about-icon {
  padding-right: 20px;
}

.about-scrollBox {
  border: 1px solid rgba(0, 0, 0, 0.12);
  border-radius: 4px;
}

.about-scrollBox-innerBox {
  padding: 1.2em;
  spacing: 1.2em;
}

.about-description {
  padding-top: 4px;
}

.about-version {
  padding-left: 7px;
}

.expo-workspaces-name-entry {
  font-size: 11.25pt;
  font-weight: 400;
  background-color: rgba(255, 255, 255, 0.04);
  color: #fff;
  padding: 0 8px;
  selection-background-color: rgba(255, 255, 255, 0.3);
  selected-color: #fff;
  caret-color: #fff;
  text-align: center;
  height: 32px;
  border-radius: 4px 4px 0 0;
  -cinnamon-caption-spacing: 12px;
}

#selected.expo-workspaces-name-entry {
  color: #fff;
  background-color: rgba(255, 255, 255, 0.3);
}

.expo-workspaces-name-entry:focus {
  color: #fff;
  box-shadow: inset 0 -2px #fff;
}

.expo-workspaces-name-entry:hover {
  background-color: rgba(255, 255, 255, 0.2);
}

.notification-applet-padding {
  padding: .5em 1em;
}

.notification-applet-container {
  max-height: 100px;
}

.check-box CinnamonGenericContainer {
  spacing: 8px;
}

.check-box:focus:checked StBin {
  background-image: url(assets/checkbox.svg);
}

.check-box:checked StBin {
  background-image: url(assets/checkbox.svg);
}

.radiobutton CinnamonGenericContainer {
  spacing: 8px;
}

.radiobutton:focus:checked StBin {
  background-image: url(assets/radiobutton.svg);
}

.radiobutton:checked StBin {
  background-image: url(assets/radiobutton.svg);
}

.flashspot {
  background-color: #1967d2;
}

.osd-window {
  spacing: 1em;
  padding: 16px;
}

.osd-window .level {
  height: 0.7em;
  border-radius: 0.3em;
  background-color: rgba(0, 0, 0, 0.26);
}

.osd-window .level-bar {
  border-radius: 0.3em;
  background-color: #1967d2;
}

.tile-hud:top {
  border-top-width: 0;
  border-radius: 0 0 10px 10px;
}

.tile-hud:bottom {
  border-bottom-width: 0;
  border-radius: 4px 4px 0 0;
}

.tile-hud:left {
  border-left-width: 0;
  border-radius: 0 10px 10px 0;
}

.tile-hud:right {
  border-right-width: 0;
  border-radius: 10px 0 0 10px;
}

.tile-hud:top-left {
  border-top-width: 0;
  border-left-width: 0;
  border-radius: 0 0 10px 0;
}

.tile-hud:top-right {
  border-top-width: 0;
  border-right-width: 0;
  border-radius: 0 0 0 10px;
}

.tile-hud:bottom-left {
  border-bottom-width: 0;
  border-left-width: 0;
  border-radius: 0 10px 0 0;
}

.tile-hud:bottom-right {
  border-bottom-width: 0;
  border-right-width: 0;
  border-radius: 10px 0 0 0;
}

.systray {
  spacing: 4px;
}

.user-box {
  padding: 0.4em 1.3em;
  spacing: 10px;
}

.user-icon {
  padding: 4px;
  border: none;
}

.user-label {
  font-size: 10.5pt;
  font-weight: 500;
  color: rgba(0, 0, 0, 0.87);
}
